@@ -59,6 +59,15 @@ def check_row(row):
     return not any({row[k] is None: row[k] for k in row})
 
 
+class Subtask:
+    name: str
+    max_points: float
+
+    def __init__(self, name: str, max_points: float):
+        self.name = name
+        self.max_points = max_points
+
+
 class Ep2Group:
 
     def __init__(self, ep2, name):
@@ -291,7 +300,8 @@ class Ep2:
 
     def tutor_repo(self):
         """Returns the path to the local tutor directory"""
-        return os.path.join(self.config.get('Local', 'GitHome'), 'org', 'tutorinnen')
+        return self.config.get('Local', 'TutorRepo',
+                               fallback=os.path.join(self.config.get('Local', 'GitHome'), 'org', 'tutorinnen'))
 
     def tutor_gender(self):
         """Returns the gender of a tutor"""
@@ -391,6 +401,38 @@ class Ep2:
         click.secho('* {:^56s} *'.format('Performing actions as {:s}'.format(user.name)), fg='red', bold=True)
         click.secho('*' * 60, fg='red', bold=True)
 
+    def exercise_subtasks_csv(self, ex: int):
+        return os.path.join(self.tutor_repo(), "ex_info", "ex_{}.csv".format(ex))
+
+    def get_exercise_subtasks(self, ex: int) -> [Subtask]:
+        csv_file = self.exercise_subtasks_csv(ex)
+
+        with open(csv_file, 'r') as infile:
+            reader = csv.DictReader(infile, ['subtask', 'max_points'], KEY_INVALID, strict=True)
+
+            headers = next(reader, None)
+            if not validate_headers(headers):
+                click.secho('Malformed file: %s. Invalid headers!' % csv_file)
+                exit(1)
+
+            subtasks: [Subtask] = []
+            for row in reader:
+                subtasks += [Subtask(row['subtask'], float(row['max_points']))]
+
+            return subtasks
+
+    def validate_grading(self, ex: int, grading: str) -> (bool, [float]):
+        subtasks = self.get_exercise_subtasks(ex)
+        grading = grading.split('/')
+
+        if len(subtasks) != len(grading):
+            return False, []
+
+        grading = [float(grade) for grade in grading]
+        correct = all([grade <= max_points for (grade, max_points) in zip(grading, [subtask.max_points for subtask in subtasks])])
+
+        return correct, grading
+
 
 def verify_and_normalize_student_id(student_id) -> Result:
     import re
