@@ -383,7 +383,7 @@ def submit(ctx, group: str, ue: int):
     template.tutor_gender = ep2.tutor_gender()
     template.subtasks = ep2.get_exercise_subtasks(ue)
 
-    with open(exercise_csv_file, 'r') as infile:
+    with open(exercise_csv_file, 'r', encoding='utf-8') as infile:
         reader = csv.DictReader(infile, fnames, KEY_INVALID, strict=True)
 
         headers = next(reader, None)
@@ -393,7 +393,7 @@ def submit(ctx, group: str, ue: int):
             exit(1)
 
         f_info.open_write(exercise_csv_file_tmp, True)
-        with open(exercise_csv_file_tmp, 'w') as outfile:
+        with open(exercise_csv_file_tmp, 'w', encoding='utf-8') as outfile:
             writer = csv.DictWriter(outfile, fnames, lineterminator='\n')
 
             writer.writeheader()
@@ -450,9 +450,10 @@ def submit(ctx, group: str, ue: int):
                 template.student_gender = stud_data[KEY_STUDENT_GENDER]
 
                 issue = template.__str__()
+                click.echo(issue.replace('\n\n', '\n'))
                 click.echo('Issue for %s - %s, %s\n' % (row[KEY_STUDENT_ID], stud_data[KEY_STUDENT_NAME_LAST].upper(),
                                                         stud_data[KEY_STUDENT_NAME_FIRST]))
-                click.echo(issue.replace('\n\n', '\n'))
+
                 click.echo('\n' + ('=' * 30) + '\n')
                 issues += [(row[KEY_STUDENT_ID], issue)]
 
