@@ -598,8 +598,7 @@ def submit(ctx, group, ue):
         for student_id, issue in bar:
             student_project = ep2.ue_repo(student_id)  # get project
             try:
-                project = ep2.gitlab.projects.get(student_project, lazy=True)  # fetch project (gitlab) and add issue
-                project.issues.create({'title': 'Übungstest %s' % ue, 'description': issue})
+                ep2.create_project_issue(project=student_project, title='Übungstest %s' % ue, descrition=issue)
             except gitlab.GitlabCreateError as e:
                 exceptions += [(e, student_project)]
 
